#! /bin/bash
echo "Generate the main window"
pyuic5 -o robot_log_visualizer/ui/autogenerated/visualizer.py robot_log_visualizer/ui/misc/visualizer.ui

echo "Generate About"
pyuic5 -o  robot_log_visualizer/ui/autogenerated/about.py robot_log_visualizer/ui/misc/about.ui

echo "Generate tab"
pyuic5 -o  robot_log_visualizer/ui/autogenerated/plot_tab.py robot_log_visualizer/ui/misc/plot_tab.ui
pyuic5 -o  robot_log_visualizer/ui/autogenerated/video_tab.py robot_log_visualizer/ui/misc/video_tab.ui

echo "The ui is generated"
